﻿using System.Collections.ObjectModel;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Interactivity;

namespace CustomContolTest
{
    public class BehaviorCreatorCollection : Collection<Behavior> { }

    public static class BehaviorInStyleAttacher
    {
        #region Attached Properties

        public static readonly DependencyProperty BehaviorsProperty =
            DependencyProperty.RegisterAttached(
                "Behaviors",
                typeof(BehaviorCreatorCollection),
                typeof(BehaviorInStyleAttacher),
                new UIPropertyMetadata(null, OnBehaviorsChanged));

        #endregion

        #region Getter and Setter of Attached Properties

        public static BehaviorCreatorCollection GetBehaviors(TreeView treeView)
        {
            return (BehaviorCreatorCollection)treeView.GetValue(BehaviorsProperty);
        }

        public static void SetBehaviors(
            TreeView treeView, BehaviorCreatorCollection value)
        {
            treeView.SetValue(BehaviorsProperty, value);
        }

        #endregion

        #region on property changed methods


        private static void OnBehaviorsChanged(DependencyObject depObj, DependencyPropertyChangedEventArgs e)
        {
            if (e.NewValue is BehaviorCreatorCollection == false)
                return;

            var newBehaviorCollection = e.NewValue as BehaviorCreatorCollection;

            var behaviorCollection = Interaction.GetBehaviors(depObj);
            behaviorCollection.Clear();
            foreach (var behavior in newBehaviorCollection)
            {
                behaviorCollection.Add(behavior);
            }
        }

        #endregion
    }

}
